#!/bin/bash

# define the variables
target=${1}
file_ext_regex="\(.module$\|.php$\|.inc$\|.test$\|.js$\|.install$\|.css$\|.profile$\|.info$\)"

# check if the version is set
if [ "${target}" = "" ]; then
  echo "Usage:"
  echo "  $ <path to file_integrity>/create_core_hashes.sh <path to file_integrity>/hashes/drupal-<drupal version>.hashes"
  echo
  echo "Example:"
  echo "  $ sites/all/modules/file_integrity/create_core_hashes.sh sites/all/modules/file_integrity/hashes/drupal-6.6.hashes"
  exit 1
fi

# do a basic check if we are in the base Drupal directory
if [ ! -d "includes" -o ! -d "modules" -o ! -f "index.php" ]; then
  echo "Drupal base files not found. Are you sure you're running me from the base directory?"
  exit 1
fi

# check if the hashes dir exists
if [ ! -d `dirname "${target}"` ]; then
  echo "Target directory \"`dirname \"${target}\"`\" does not exist."
  exit 1
fi

# find all core Drupal files and save them in the hashes file
find . -type f | grep -v "^./sites/" | grep "${file_ext_regex}" | xargs md5sum > ${target}
md5sum "./sites/default/default.settings.php" >> ${target}
echo "Hashes successfully saved in \"${target}\"."
